pygeodesy.auxilats.auxAngle.AuxChi

Package pygeodesy :: Package auxilats :: Module auxAngle :: Class AuxChi |
[frames] | no frames]

# Class AuxChi

      object --+
               |
    named._Named --+
                   |
            AuxAngle --+
                       |
                      AuxChi

A Conformal, Auxiliary latitude.

Instance Methods
Inherited from `AuxAngle`: `__abs__`, `__add__`, `__bool__`, `__eq__`, `__float__`, `__iadd__`, `__init__`, `__isub__`, `__ne__`, `__neg__`, `__pos__`, `__radd__`, `__rsub__`, `__str__`, `__sub__`, `copyquadrant`, `normal`, `toBeta`, `toChi`, `toMu`, `toPhi` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
fromDegrees(deg, **name) Get an AuxChi from degrees. |
Inherited from `AuxAngle`: `fromLambertianDegrees`, `fromLambertianRadians`, `fromRadians`

Properties
Inherited from `AuxAngle`: `diff`, `iteration`, `normalized`, `tan`, `toDegrees`, `toLambertianDegrees`, `toLambertianRadians`, `toRadians`, `x`, `y` Inherited from `named._Named`: `classname`, `classnaming`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### fromDegrees (deg, **name) Static Method |
Get an AuxChi from degrees. Overrides: AuxAngle.fromDegrees